FileState

Struct FileState 

pub struct FileState {
    pub datum: Datum,
    pub base_location: UtmLocation,
    pub utm_zone: Option<u8>,
    pub file_convergence: Option<FileConvergence>,
    pub project_parameters: Option<ProjectParameters>,
}
State captured when a .dat file is encountered during project parsing.

Compass uses rolling state - each file captures whatever state was active at the moment it was parsed. This allows different files in the same project to have different datums, base locations, etc.

Fields

datum: Datum

The datum active when this file was encountered

base_location: UtmLocation

The base location active when this file was encountered

utm_zone: Option<u8>

The UTM zone for fixed stations (optional)

file_convergence: Option<FileConvergence>

File-level convergence parameter (optional)

project_parameters: Option<ProjectParameters>

Project-level parameter flags (optional)